function plot(varargin)
% plot - Plots convex hull of vertices that are projected onto the first
% and second coordinate
%
% Syntax:  
%    plot(V)
%
% Inputs:
%    V - vertices object 
%
% Outputs:
%    none
%
% Example: 
%    V=vertices(rand(2,6));
%    plot(V)
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Author: Matthias Althoff
% Written: 30-September-2006 
% Last update: 22-March-2007
% Last revision: ---

%------------- BEGIN CODE --------------

%If only one argument is passed
if nargin==1
    V=varargin{1};
    type='frame';
    
%If two arguments are passed    
elseif nargin==2
    V=varargin{1};
    type=varargin{2};
    
%If three arguments are passed    
elseif nargin==3
    V=varargin{1};
    type=varargin{2};  
    val=varargin{3};  
    
%If too many arguments are passed
else
    disp('Error: too many inputs');
    V=varargin{1};
    type=varargin{2};    
end


%check if vertex array is not empty
if ~isempty(V.V)

    %Obtain x- and y- coordinates of potential vertices
    xPotential=V.V(1,:);
    yPotential=V.V(2,:);

    %Plot if there are more than two points
    if length(xPotential)>2
        %determine vertex indices for convex hull vertices from potential
        %vertices 
        try
            vertexIndices=convhull(xPotential,yPotential);
        catch
            disp('plot failed');
            vertexIndices=[];
        end
    else
        vertexIndices=[1 2];
    end
    
    if ~isempty(vertexIndices)
        %Select convex hull vertices
        xCoordinates=xPotential(vertexIndices);
        yCoordinates=yPotential(vertexIndices);

        %Plot convex hull and crosses for vertices
        %plot(xCoordinates,yCoordinates,'b-',...
        %     xCoordinates,yCoordinates,'r+');

        hold on
        %try to use linespec
        try
            plot(xCoordinates,yCoordinates,type);  
        %use one of the special definitions
        catch
            if strcmp(type,'frame')
                plot(xCoordinates,yCoordinates,'b-');  
            elseif strcmp(type,'filledFrame')
                fill(xCoordinates,yCoordinates,'w','EdgeColor','b'); 
            elseif strcmp(type,'greenFrame')
                fill(xCoordinates,yCoordinates,'w','EdgeColor','g');            
            elseif strcmp(type,'lightgray')
                fill(xCoordinates,yCoordinates,[.75 .75 .75],'EdgeColor','none');
            elseif strcmp(type,'gray')
                fill(xCoordinates,yCoordinates,[.675 .675 .675],'EdgeColor','none');    
            elseif strcmp(type,'darkgray')
                fill(xCoordinates,yCoordinates,[.6 .6 .6],'EdgeColor','none');
            elseif strcmp(type,'black')
                fill(xCoordinates,yCoordinates,[.0 .0 .0],'EdgeColor','none');               
            elseif strcmp(type,'grayEdge')
                plot(xCoordinates,yCoordinates,'Color',[.8 .8 .8]); 
            elseif strcmp(type,'grayEdgeThick')
                plot(xCoordinates,yCoordinates,'Color',[.8 .8 .8],'lineWidth',3);
            elseif strcmp(type,'blackEdge')
                plot(xCoordinates,yCoordinates,'k-','lineWidth',2);   
            elseif strcmp(type,'blackEdgeThick')
                plot(xCoordinates,yCoordinates,'k-','lineWidth',3);   
            elseif strcmp(type,'whiteEdge')
                plot(xCoordinates,yCoordinates,'w-','lineWidth',2);
            elseif strcmp(type,'whiteEdgeDashed')
                plot(xCoordinates,yCoordinates,'w--','lineWidth',2);
            elseif strcmp(type,'blackFrame')
                fill(xCoordinates,yCoordinates,'w','EdgeColor','k'); 
                %plot(xCoordinates,yCoordinates,'k-');           
            elseif strcmp(type,'grayFrame')
                fill(xCoordinates,yCoordinates,[.8 .8 .8],'EdgeColor','k');  
            elseif strcmp(type,'grayTones')
                l=linspace(1,0,100)';
                colormap([l,l,l]); 
                fill(xCoordinates,yCoordinates,val,'EdgeColor','none');            
            elseif strcmp(type,'vertices')
                plot(xCoordinates,yCoordinates,'k+');   
            elseif strcmp(type,'2dIn3d')
                zCoordinates=10*ones(length(xCoordinates),1);
                plot3(xCoordinates,yCoordinates,zCoordinates,'k-');             
            end
        end
    end
end


%------------- END OF CODE --------------