function inputSet = errorSolution(obj,V,options)
% errorSolution - computes the solution due to the linearization error
%
% Syntax:  
%    inputSet = errorSolution(obj,V,options)
%
% Inputs:
%    obj - linear system object
%    V - set of linearization errors
%    options - options struct
%
% Outputs:
%    inputSet - reachable set due to the linearization error
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: ---

% Author:       Matthias Althoff
% Written:      18-January-2008 
% Last update:  27-May-2011
% Last revision:---

%------------- BEGIN CODE --------------

%load data from object/options structure
r=options.timeStep;

%initialize the reachable set due to input
inputSet = V*r;

%matrix zonotope
for i=1:length(obj.power.zono)
    taylorTerm = obj.power.zono{i}*(r/factorial(i+1));
    inputSet = inputSet + taylorTerm*V;
end
%interval matrix
for i=(length(obj.power.zono)+1):length(obj.power.int)
    taylorTerm = obj.power.int{i}*(r/factorial(i+1));
    inputSet = inputSet + taylorTerm*V;
end

%remainder term
Vabs=zonotope(abs(intervalhull(V)));
inputSet = inputSet + obj.E*r*Vabs;

%delete zero generators in zonotope representation
inputSet=deleteZeros(inputSet);


%------------- END OF CODE --------------