function [obj] = jacobians(obj,options)
% jacobians - computes the jacobians of the nonlinear system in a symbolic
% way; the result is stored in a m-file and passed by a handle
%
% Syntax:  
%    [obj] = jacobians(obj)
%
% Inputs:
%    obj - nonlinear system object
%
% Outputs:
%    obj - nonlinear system object
%
% Example: 
%    Text for example...
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: 

% Author:       Matthias Althoff
% Written:      29-October-2007 
% Last update:  07-September-2012
% Last revision:---

%------------- BEGIN CODE --------------


%create symbolic variables
[x,u] = symVariables(obj,'LRbrackets');

%insert symbolic variables into the system equations
t = 0;
fdyn = obj.mFile(t,x,u);

disp('create Jacobians');

%compute jacobian with respect to the state
Jdyn.x = jacobian(fdyn,x);

%compute jacobian with respect to the input
Jdyn.u = jacobian(fdyn,u);

disp('create 2nd order Jacobians');

%compute second order jacobians using 'LR' variables
Jdyn_comb = jacobian(fdyn,[x;u]);
%dynamic jacobians
for k=1:length(Jdyn_comb(:,1))
    %Calculate 2nd order Jacobians
    J2dyn(k,:,:)=jacobian(Jdyn_comb(k,:),[x;u]);
end

if options.tensorOrder>2

    disp('create 3rd order Jacobians');
    dim = length(J2dyn(:,1,1));
    vars = length(J2dyn(1,:,1));
    J3dyn = sym(zeros(dim,vars,vars,vars));

    %compute third order jacobians using 'LR' variables
    for k=1:length(J2dyn(:,1,1))
        for l=1:length(J2dyn(1,:,1))
            %Calculate 3rd order Jacobians
            J3dyn(k,l,:,:)=jacobian(J2dyn(k,l,:),[x;u]);
        end
    end
end

disp('create mFiles')

%generate mFile that computes the Lagrange remainder and the jacobian
createJacobianFile(Jdyn,options.path);
%createRemainderFile(J2dyn,J2con,options.path);

if options.tensorOrder>2
    createHessianTensorFile(J2dyn,options.path,0);
    create3rdOrderTensorFile(J3dyn,options.path);
    %create3rdOrderTensorFile_wReplacements(J3dyn,options.path,options.replacements);
else
    createHessianTensorFile(J2dyn,options.path,1);
end


% %create symbolic variables
% [x,u]=symVariables(obj,'LRbrackets');
% 
% %insert symbolic variables into the system equations
% t=0;
% fLR=obj.mFile(t,x,u);
% 
% %compute jacobian with respect to the state
% Jx=jacobian(fLR,x);
% %obj.jacobians.firstOrder.x=simple(Jx);
% obj.jacobians.firstOrder.x=Jx;
% 
% %compute jacobian with respect to the input
% Ju=jacobian(fLR,u);
% %obj.jacobians.firstOrder.u=simple(Ju);
% obj.jacobians.firstOrder.u=Ju;
% 
% %compute second order jacobians using 'LR' variables
% J=jacobian(fLR,[x;u]);
% for k=1:length(J(:,1))
%     %Calculate 2nd order Jacobians
%     Jxu=jacobian(J(k,:),[x;u]);
%     %obj.jacobians.secondOrder(k,:,:)=simple(Jxu);
%     obj.jacobians.secondOrder(k,:,:)=Jxu;
% end
% 
% if options.tensorOrder>2
% 
%     disp('create 3rd order Jacobians');
% 
%     %compute third order jacobians using 'LR' variables
%     for k=1:length(J2dyn(:,1,1))
%         for l=1:length(J2dyn(1,:,1))
%             %Calculate 2nd order Jacobians
%             J3dyn(k,l,:,:)=jacobian(J2dyn(k,l,:),[x;u]);
%         end
%     end
% end
% 
% %generate mFile that computes the lagrange remainder and the jacobian
% createJacobianFile(obj,options);
% createRemainderFile(obj,options);
% 
% if options.tensorOrder>2
%     createHessianTensorFile(J2dyn,options.path,0);
%     create3rdOrderTensorFile(J3dyn,options.path);
% else
%     createHessianTensorFile(J2dyn,options.path,1);
% end

%------------- END OF CODE --------------