function normalVecToGeneratorsAdj(Z)
% exactPolytope - Converts a zonotope from a G- to a H-representation
%
% Syntax:  
%    [P] = exactPolytope(Z)
%
% Inputs:
%    Z - zonotope object
%
% Outputs:
%    P - polytope object
%
% Example: 
%    Z=zonotope(rand(2,5));
%    P=polytope(Z);
%    plot(P);
%    hold on
%    plot(Z);
%
% Other m-files required: vertices, polytope
% Subfunctions: none
% MAT-files required: none
%
% See also: intervalhull,  vertices

% Author: Matthias Althoff
% Written: 01-April-2010
% Last update: ---
% Last revision: ---

%------------- BEGIN CODE --------------

%transform zonotope to the center
c=center(Z);
Z=Z+(-c);


G=Z.Z(:,2:end);
%normalize G
for i=1:length(G(1,:))
    G(:,i)=G(:,i)/norm(G(:,i));
end

%generate polytope
P=exactPolytope(Z);
[H,k]=double(P);

dim=length(H(1,:));
Gnew=[];

%remove mirrored halfspaces
l=length(k);
C=H(1:l/2,:);
d=k(1:l/2);

%initial point is on nearest halfspace
[dVal,dInd]=sort(d);
point=C(dInd(1),:)'*d(dInd(1));


for i=1:4

    %check nearest fecets
    adjInd=adjFacets(C,d,point,dim-2);


    %compute generator
    indices=[dInd(1),adjInd];
    Q=C(indices,:)';
    v=ndimCross(Q);
    Gnew(:,end+1)=v'/norm(v);

    %get new point
    point=C(adjInd(1),:)'*d(adjInd(1));
end

G
Gnew


%--------------------------------------------------------------------------
function adjacentInd=adjFacets(C,d,point,number)

dist=C*point-d;
dist=abs(dist);

%get adjacent facets, first element is the facet where the point is on.
[sortDist, sortInd]=sort(dist);

%return adjacent indices
adjacentInd=sortInd(2:2+number-1);





%------------- END OF CODE --------------