function bouncingBall()
% updated: 31-January-2012, MA

%set options---------------------------------------------------------------
options.x0 = [1; 0]; %initial state for simulation
options.R0 = zonotope([options.x0, diag([0.05, 0.05])]); %initial state for reachability analysis
options.startLoc = 1; %initial location
options.finalLoc = 0; %0: no final location
options.tStart = 0; %start time
options.tFinal = 5; %final time
options.timeStepLoc{1} = 0.05; %time step size for reachable set computation in location 1
options.taylorTerms = 10;
options.zonotopeOrder = 20;
options.polytopeOrder = 10;
options.errorOrder=2;
options.reductionTechnique = 'girard';
options.isHybrid = 1;
options.isHyperplaneMap = 0;
options.enclosureEnables = [5]; %choose enclosure method(s)
options.originContained = 0;
options.polytopeType = 'mpt';
%--------------------------------------------------------------------------

%obtain factors for initial state and input solution; this has to be hidden
%in the corresponding classes; future work
for i=1:(options.taylorTerms+1)
    r = options.timeStepLoc{1};
    options.factor(i)= r^(i)/factorial(i);    
end

%specify hybrid automaton--------------------------------------------------
%specify linear system of bouncing ball
A = [0 1; 0 0];
B = eye(2); % no loss of generality to specify B as the identity matrix
linSys = linearSys('linearSys',A,B);

%define large and small distance
dist = 1e3;
eps = 1e-6;

%invariant
inv = intervalhull([-2*eps, dist; -dist, dist]);
%guard sets
guard = intervalhull([- eps, 0; -dist, 0]); 
%resets
reset.A = [0, 0; 0, -0.75]; reset.b = zeros(2,1);
%transitions
trans{1} = transition(guard,reset,1,'a','b'); %--> next loc: 1; 'a', 'b' are dummies
%specify location
loc{1} = location('loc1',1,inv,trans,linSys); 
%specify hybrid automata
HA = hybridAutomaton(loc); % for "geometric intersection"
%--------------------------------------------------------------------------

%set input:
options.uLoc{1} = [0; -1]; %input for simulation
options.uLocTrans{1} = options.uLoc{1}; %input center for reachability analysis
options.Uloc{1} = zonotope(zeros(2,1)); %input deviation for reachability analysis

%simulate hybrid automaton
HA = simulate(HA,options); 

%compute reachable set
[HA] = reach(HA,options);

%choose projection and plot------------------------------------------------
options.projectedDimensions = [1 2];
options.plotType = 'b';
plot(HA,'reachableSet',options); %plot reachable set
plot(options.R0,options.projectedDimensions,'blackFrame'); %plot initial set
plot(HA,'simulation',options); %plot simulation
%--------------------------------------------------------------------------

